==> nextcloud-25.0.7.tgz: nextcloud/apps/photos/l10n/pt_PT.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Hiperligação Pública",
    "Photos" : "Fotos",
    "Your memories under your control" : "As suas memórias estão sob o seu controlo",
    "Videos" : "Videos",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "Shared with you" : "Partilhado consigo",
    "Tags" : "Etiquetas",
    "Back" : "Anterior",
    "Save" : "Guardar",
    "Copy public link" : "Copiar ligação publica",
    "An error occurred" : "Ocorreu um erro",
    "Open the full size \"{name}\" image" : "Abrir a foto \"{name}\" no tamanho original",
    "Open the \"{name}\" sub-directory" : "Abrir a sub-diretoria \"{name}\"",
    "Back to {folder}" : "Ir para {folder}",
    "Share this folder" : "Partilhar esta pasta",
    "Enable squared photos view" : "Ativar vista de fotos quadradas",
    "View" : "Ver",
    "Favorite" : "Favorito",
    "Remove from favorites" : "Remover dos favoritos",
    "No photos in here" : "Aqui não existem fotos ",
    "Shared by" : "Partilhado por",
    "Shared albums" : "Álbuns partilhados",
    "No tags yet" : "Ainda sem marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Add" : "Adicionar",
    "Tagged photos" : "Fotos marcadas",
    "Failed to delete {fileName}." : "Falha ao remover {fileName}.",
    "Your photos" : "As suas fotos",
    "Your videos" : "Os seus vídeos",
    "Your folders" : "As suas pastas",
    "Locations" : "Localizações",
    "Settings" : "Configurações"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-26.0.9.tgz: nextcloud/apps/photos/l10n/pt_PT.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Hiperligação Pública",
    "Photos" : "Fotos",
    "Your memories under your control" : "As suas memórias estão sob o seu controlo",
    "Videos" : "Videos",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "Shared with you" : "Partilhado consigo",
    "Tags" : "Etiquetas",
    "Back" : "Anterior",
    "Save" : "Guardar",
    "Shared by" : "Partilhado por",
    "No recommendations. Start typing." : "Nenhuma recomendação. Comece a escrever ",
    "Group" : "Grupo",
    "Copy public link" : "Copiar ligação publica",
    "An error occurred" : "Ocorreu um erro",
    "Open the full size \"{name}\" image" : "Abrir a foto \"{name}\" no tamanho original",
    "Open the \"{name}\" sub-directory" : "Abrir a sub-diretoria \"{name}\"",
    "Back to {folder}" : "Ir para {folder}",
    "Share this folder" : "Partilhar esta pasta",
    "Enable squared photos view" : "Ativar vista de fotos quadradas",
    "View" : "Ver",
    "Favorite" : "Favorito",
    "Remove from favorites" : "Remover dos favoritos",
    "No photos in here" : "Aqui não existem fotos ",
    "No tags yet" : "Ainda sem marcações",
    "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
    "Add" : "Adicionar",
    "Tagged photos" : "Fotos marcadas",
    "Details" : "Detalhes",
    "Failed to delete {fileName}." : "Falha ao remover {fileName}.",
    "Locations" : "Localizações",
    "Shared albums" : "Álbuns partilhados"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
